from __future__ import absolute_import
from linecache import getline


__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2010-2016 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.0.1'
__uuid__='af90cc0c-de54-4a32-becd-06f5ce5a3a75'

__docformat__ = "restructuredtext en"

import unittest
import os
import tests.CheckNormpathX

import filesysobjects.FileSysObjects

#
#######################
#

class CallUnits(tests.CheckNormpathX.CheckNormpathX):
    
    def testCase000(self):
        _in    = '\\a'
        _norm  = os.path.normpath('\\a')
        self.check_normpathX(_in,_norm,'local')

    def testCase001(self):
        _in    = '\a'
        _norm  = os.path.normpath('\a')
        self.check_normpathX(_in,_norm,'local')

    def testCase002(self):
        _in    = r'\a'
        _norm  = os.path.normpath(r'\a')
        self.check_normpathX(_in,_norm,'local')

    def testCase010(self):
        _in    = 'd:\\a'
        _norm  = os.path.normpath('d:\\a')
        self.check_normpathX(_in,_norm,'local')

    def testCase011(self):
        _in    = 'd:\a'
        _norm  = os.path.normpath('d:\a')
        self.check_normpathX(_in,_norm,'local')

    def testCase012(self):
        _in    = 'd:/a'
        _norm  = os.path.normpath('d:/a')
        self.check_normpathX(_in,_norm,'local')

    def testCase020(self):
        _in    = 'd:\\'
        _norm  = os.path.normpath('d:\\')
        self.check_normpathX(_in,_norm,'local')

    def testCase021(self):
        _in    = 'd:/'
        _norm  = os.path.normpath('d:/')
        self.check_normpathX(_in,_norm,'local')

    def testCase030(self):
        _in    = '/a/b/c'
        _norm  = os.path.normpath('/a/b/c')
        self.check_normpathX(_in,_norm,'local')


#
#######################
#

if __name__ == '__main__':
    unittest.main()




from __future__ import absolute_import
from linecache import getline


__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2010-2016 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.0.1'
__uuid__='af90cc0c-de54-4a32-becd-06f5ce5a3a75'

__docformat__ = "restructuredtext en"

import unittest
import os,sys

import filesysobjects.FileSysObjects
import pysourceinfo.PySourceInfo

#
#######################
#


class CallUnits(unittest.TestCase):
    """Network resources IEEE.1003.1/CIFS/SMB/UNC - respect hostname
    Respect 'hostname', which is actual hostname, and a node name.
    """
    @classmethod
    def setUpClass(self):
        self.top = filesysobjects.FileSysObjects.normpathX('hostname/')
        self.start = filesysobjects.FileSysObjects.normpathX('d://hostname/tests//////a/b/hostname//c////////d/tests/b///c')
        
    def testCase000(self):
        startRef = [('LDSYS', '', 'd:', filesysobjects.FileSysObjects.normpathX('/hostname/tests/a/b/hostname/c/d/tests/b/c'))]
        ret = filesysobjects.FileSysObjects.splitPathVar(self.start,appsplit=True)
        self.assertEqual(startRef, ret) 

    def testCase001(self):
        topRef = [('LFSYS', '', '', 'hostname')]
        ret = filesysobjects.FileSysObjects.splitPathVar(self.top,appsplit=True)
        self.assertEqual(topRef, ret) 


    def testCase002(self):
        top0ref=filesysobjects.FileSysObjects.normpathX('d:/hostname')
        topRef = [('LDSYS', '', 'd:', filesysobjects.FileSysObjects.normpathX('/hostname'))]
        top = filesysobjects.FileSysObjects.getTopFromPathString(self.top, [self.start])
        ret = filesysobjects.FileSysObjects.splitPathVar(top,appsplit=True)

        self.assertEqual(top0ref, top) 
        self.assertEqual(topRef, ret) 
        pass


#
#######################
#

if __name__ == '__main__':
    unittest.main()




from __future__ import absolute_import
from linecache import getline


__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2010-2016 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.0.1'
__uuid__='af90cc0c-de54-4a32-becd-06f5ce5a3a75'

__docformat__ = "restructuredtext en"

import unittest
import os
import tests.CheckNormpathX

import filesysobjects.FileSysObjects

#
#######################
#

class CallUnits(tests.CheckNormpathX.CheckNormpathX):
    
    def testCase040(self):
        _in    = 'd:/'
        _norm  = 'd:'
        self.check_normpathX(_in,_norm,'cnp')
        
    def testCase041(self):
        _in    = 'd:\\'
        _norm  = 'd:\\' 
        self.check_normpathX(_in,_norm, 'cnp')
        pass
    

#
#######################
#

if __name__ == '__main__':
    unittest.main()




"""Create a plist, find a matching relative filepathname in directory tree.

Calling elementary functions.

* **Data**:
  ::
  
    see 'testdata.examples'
  
  refer also to the manual `[filesystem-elements-as-objects] <path_syntax.html#filesystem-elements-as-objects>`_

* **Call**:
  ::

    import testdata
    import filesysobjects.FileSysObjects
      
    # start of upward search - file is converted into it's containing directory node
    s = os.sep
    any_sub_path = os.path.normpath('examples/a/b0/c/a/b0/c/F')
    spath  = testdata.mypath
    spath += any_sub_path

    # Here an empty list is used for search only. The function adds 
    # entries to the provided list storage, thus e.g. to 'sys.path' too.
    _plist = []

    # 0. build a search path list - if not yet available
    #    adds each directory from spath to its matching 
    #    subnode  "a/b"
    #
    setUpperTreeSearchPath(spath,os.path.normpath('a/b0'), _plist)

    # 1. make it canonical - optional, here just a demo
    clearPath(_plist,**{'redundant':True,'shrink':True}) # and clear them immediately

    # 2.a. find the requested entry
    rp = findRelPathInSearchPath("F[0-5]*",_plist)

    # 2.b. find the requested entry - here as demo with a relative path
    rp = findRelPathInSearchPath("c/*/b0/F[0-5]*",_plist)

    
* **Result**:
  ::

    expected = os.path.normpath(testdata.mypath+'/examples/a/b0/c/a/b0/F1')

"""
from __future__ import absolute_import
from __future__ import print_function
import filesysobjects

__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2010-2016 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.0.1'
__uuid__='af90cc0c-de54-4a32-becd-06f5ce5a3a75'

__docformat__ = "restructuredtext en"

import unittest
import os,sys

from filesysobjects.FileSysObjects import setUpperTreeSearchPath
from filesysobjects.FileSysObjects import findRelPathInSearchPath
from filesysobjects.FileSysObjects import getTopFromPathString

#
#######################
#

class CallUnits(unittest.TestCase):
    
    def testCase000(self):
        _s = sys.path[:]

        import testdata
        import filesysobjects.FileSysObjects
          
        s = os.sep
        
        # start of upward search - file is converted into it's containing directory node
        any_sub_path = os.path.normpath('examples/a/b0/c/a/b0/c/F')
        spath  = testdata.mypath
        spath += s+ any_sub_path

        # check environment
        assert os.path.exists(spath)
                
        # store new search list, here without required sys.path
        _plist = []


        # 0. build a search path list - if not yet available
        #    adds each directory from spath to its matching 
        #    subnode  "a/b"
        #
        setUpperTreeSearchPath(spath,os.path.normpath('a/b0'), _plist)
        _plist_ref = [ # expected plist
            os.path.normpath(testdata.mypath+'/examples/a/b0/c/a/b0/c'),
            os.path.normpath(testdata.mypath+'/examples/a/b0/c/a/b0'),
            os.path.normpath(testdata.mypath+'/examples/a/b0/c/a'),
            os.path.normpath(testdata.mypath+'/examples/a/b0/c'),
            os.path.normpath(testdata.mypath+'/examples/a/b0'),
        ]
        assert _plist_ref == _plist 


        sp = os.path.normpath('a/b0/new/branch')
        expected = os.path.normpath(testdata.mypath+'/examples/a/b0/new/branch')
        rp = getTopFromPathString(sp,_plist)

        assert expected == rp 

        sp = os.path.normpath('b0/c/new/branch')
        expected = os.path.normpath(testdata.mypath+'/examples/a/b0/c/new/branch')
        rp = getTopFromPathString(sp,_plist)
        assert expected == rp 
    
        sp = os.path.normpath('b0/c/new/branch')
        expected = os.path.normpath(testdata.mypath+'/examples/a/b0/c/a/b0/c/new/branch')
        rp = getTopFromPathString(sp,_plist,**{'matchidx':1})
        assert expected == rp 

        sp = os.path.normpath('b0/c/new/branch')
        expected = os.path.normpath(testdata.mypath+'/examples/a/b0/c/new/branch')
        rp = getTopFromPathString(sp,_plist,**{'matchidx':1,'reverse':True,})
        assert expected == rp 

        sp = os.path.normpath('b0/c/new/branch')
        expected = os.path.normpath(testdata.mypath+'/examples/a/b0/c/a/b0/c/new/branch')
        rp = getTopFromPathString(sp,_plist,**{'matchlvl':1,})
        assert expected == rp 

        sp = os.path.normpath('b0/c/new/branch')
        expected = os.path.normpath(testdata.mypath+'/examples/a/b0/c/a/b0/c/new/branch')
        rp = getTopFromPathString(sp,_plist,**{'matchlvlupward':0,})
        assert expected == rp 

        sp = os.path.normpath('b0/c/new/branch')
        expected = os.path.normpath(testdata.mypath+'/examples/a/b0/c/new/branch')
        rp = getTopFromPathString(sp,_plist,**{'matchlvlupward':1,})
        assert expected == rp 

#
#######################
#

if __name__ == '__main__':
    unittest.main()




from __future__ import absolute_import
from linecache import getline


__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2010-2016 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.0.1'
__uuid__='af90cc0c-de54-4a32-becd-06f5ce5a3a75'

__docformat__ = "restructuredtext en"

import unittest
import os
import tests.CheckNormpathX

import filesysobjects.FileSysObjects

#
#######################
#

class CallUnits(tests.CheckNormpathX.CheckNormpathX):
    
    def testCase000(self):
        _in    = '\a'
        _norm  = r'\a' 
        self.check_normpathX(_in,_norm,'win')

    def testCase001(self):
        _in    = 'd:/a/b/c'
        _norm  = os.path.normpath('d:\\'+'a\\'+'b\c')  # used as an unaltered reference, thus prep it
        self.check_normpathX(_in,_norm,'win')

    def testCase080(self):
        _in        = 'd:/'
        _norm  = 'd:\\'
        self.check_normpathX(_in,_norm,'win')
        
    def testCase081(self):
        _in        = 'd:\\'
        _norm  = os.path.normpath('d:\\' )
        self.check_normpathX(_in,_norm,'win')
        
    def testCase082(self):
        _in        = 'd:///'
        _norm  = os.path.normpath('d:\\')
        self.check_normpathX(_in,_norm,'win')

    def testCase083(self):
        _in        = 'd:\\\\\\'
        _norm  = os.path.normpath('d:\\')
        self.check_normpathX(_in,_norm,'win')

    def testCase084(self):
        _in        = 'd:///'
        _norm  = os.path.normpath('d:\\')
        self.check_normpathX(_in,_norm,'win')

    def testCase085(self):
        _in        = 'd:\\\\\\'
        _norm  = os.path.normpath('d:\\')
        self.check_normpathX(_in,_norm,'win')

    def testCase088(self):
        _in        = 'd:\\/'
        _norm  = os.path.normpath('d:\\')
        self.check_normpathX(_in,_norm,'win')

    def testCase089(self):
        _in        = 'd:\\\\/\\\\///\\\\//////////'
        _norm  = os.path.normpath('d:\\')
#        self.check_normpathX(_in,_norm,'win')
        self.skipTest("Intermixed single backslash/escape not (yet???) provided due to exceptions.")

    def testCase090(self):
        _in        = 'd:/a\b/c'
        _norm  = os.path.normpath('d:/a/b/c')
        self.check_normpathX(_in,_norm)

    def testCase091(self):
        _in        = 'd:a\b\c'
        _norm  = os.path.normpath('d:a/b/c')
        self.check_normpathX(_in,_norm)


#
#######################
#

if __name__ == '__main__':
    unittest.main()

